/**
 * The class of file paths in the tool.
 * @class
 */
export declare class FilePath {
    /**
     * Defining the initial values of the class instance.
     * @param {string} strP - An absolute or relative to workspace path, if not, the `relativeTo` parameter must have a value.
     * @param {string} [relativeTo] - The path relative to the location of the `strP` parameter if wasn't relative to the workspace.
     * @throws {Error} If `strP` is not absolute or relative to workspace path.
     */
    constructor(strP: string, relativeTo?: string);
    /**
     * File name without extension.
     * @type {string}
     * @example
     * const p = new FilePath('example.test.js')
     * // p.name = 'example'
     */
    name: string;
    /**
     * File's parent folder/directory name.
     * @type {string}
     * @example
     * const p = new FilePath('main/example.js')
     * // p.folder = 'main'
     */
    folder: string;
    /**
     * File extension after the first dot.
     * @type {string}
     * @example
     * const p = new FilePath('example.test.js')
     * // p.extension = 'test.js'
     */
    extension: string;
    /**
     * File's absolute path before the parent folder/directory.
     * @type {string}
     * @example
     * const p = new FilePath('C:/users/someone/main/example.js')
     * // p.root = 'C:/users/someone'
     */
    root: string;
    /**
     * @returns {string} - File name with extension
     * @public
     */
    public get fullName(): string;
    /**
     * @returns {string} - Absolute file path
     * @public
     */
    public get fullPath(): string;
}
