/**
 * Find all stored paths with filtering.
 * @param {FilterOptions} [options] - If options is null, all the paths will be returned.
 * @param {FilePath[]} [toSearchIn] - If not provided, the search will be performed on the stored paths.
 * @returns {FilePath[]} - If no paths found, an empty array will be returned.
 * @example <caption>will return all stored js files</caption>
 * findPaths({ extension: 'js' })
 * @example <caption>will return all stored js and json files</caption>
 * findPaths({ extension: /^js(on)?$/ })
 */
export declare function findPaths(options?: FilterOptions, toSearchIn?: FilePath[]): FilePath[];
/**
 * Search for the first stored FilePath matching the given filter options.
 * @param {FilterOptions} options - FilePath's search filter options.
 * @param {FilePath[]} [otherPaths] - If not provided, the search will be performed on the stored paths.
 * @returns {FilePath | void} - The FilePath if found, otherwise undefined.
 * @example <caption>will return the first file called 'example'</caption>
 * const p = findPath({ name: 'example' })
 * const { ... } = (await import(p.fullPath)).default
 */
export declare function findPath(options: FilterOptions, otherPaths?: FilePath[]): FilePath | void;
import type { FilterOptions } from '../options.js';
import type { FilePath } from '../class/filePath.js';
